@@ -635,8 +635,7 @@ nsis <- function(){ ## build installer...
 ##' Print x using the message facility
 ##'
 ##' This allows the suppressMessages to work on print functions.  This
-##' captures the output via R.Util's captureOutput function and then
-##' sends it through the message routine.
+##' captures the output function sends it through the message routine.
 ##'
 ##' catpureOutput was used since it is much faster than the internal
 ##' capture.output see https://www.r-bloggers.com/performance-captureoutput-is-much-faster-than-capture-output/
@@ -647,7 +646,7 @@ nsis <- function(){ ## build installer...
 ##' @keywords internal
 nlmixrPrint <- function(x, ...){
     this.env <- environment();
-    message(invisible(paste(R.utils::captureOutput(assign("x", print(x, ...), this.env)), collapse="\n")), appendLF=TRUE);
+    message(invisible(paste(.captureOutput(assign("x", print(x, ...), this.env)), collapse="\n")), appendLF=TRUE);
     invisible(x)
 }
 
@@ -695,3 +694,5 @@ cholSE <- function(matrix, tol=(.Machine$double.eps) ^ (1 / 3)){
 .setRoot <- function(){
     setwd("c:/");
 }
+
+
